<?php
if (!function_exists('rethink_setup')) :

    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which runs
     * before the init hook. The init hook is too late for some features, such as indicating
     * support post thumbnails.
     */
    function rethink_setup() {
        /**
         * Make theme available for translation
         * Translations can be filed in the /languages/ directory
         * If you're building a theme based on rethink, use a find and replace
         * to change 'rethink' to the name of your theme in all the template files
         */
        load_theme_textdomain('rethink', get_template_directory() . '/languages');
        /**
         * Add default posts and comments RSS feed links to head
         */
        add_theme_support('automatic-feed-links');
        add_theme_support('title-tag');
        /**
         * This theme styles the visual editor with editor-style.css to match the theme style.
         */
        add_editor_style();
        /**
         * Enable support for Post Thumbnails
         */
        add_theme_support('post-thumbnails');
        add_image_size('post_thumbnail', 260, 190, true);
        /**
         * Set the content width based on the theme's design and stylesheet.
         *
         * Used to set the width of images and content. Should be equal to the width the theme
         * is designed for, generally via the style.css stylesheet.
         */
        if (!isset($content_width))
            $content_width = 738;
        /**
         * Registering custom menu
         */
        register_nav_menu('custom_menu', __('Main Menu', 'rethink'));
        $args = array(
            // Text color and image (empty to use none).
            'default-text-color' => '515151',
            'default-image' => '',
            // Set height and width, with a maximum value for the width.
            'height' => 362,
            'width' => 738,
            'max-width' => 1184,
            // Support flexible height and width.
            'flex-height' => true,
            'flex-width' => true,
            // Random image rotation off by default.
            'random-default' => false,
                // Callbacks for styling the header and the admin preview.
        );
        add_theme_support('custom-header', $args);
    }

endif;
add_action('after_setup_theme', 'rethink_setup');

/**
 * Adding class for navigation menu
 */
function rethink_add_menuclass($ulclass) {
    return preg_replace('/<ul>/', '<ul class="sf-menu">', $ulclass, 1);
}

add_filter('wp_page_menu', 'rethink_add_menuclass');

/**
 * Navigation menu
 */
function rethink_nav() {
    wp_nav_menu(array('theme_location' => 'custom_menu', 'container_id' => 'menu', 'menu_class' => 'sf-menu', 'fallback_cb' => 'rethink_nav_fallback'));
}

/**
 * Navigation menu fallback
 */
function rethink_nav_fallback() {
    ?>
    <div id="menu">
        <ul class="sf-menu">
            <?php
            wp_list_pages('title_li=&show_home=1&sort_column=menu_order');
            ?>
        </ul>
    </div>
    <?php
}

/**
 * List pages filter for navigation menu
 */
function rethink_nav_menu_items($items) {
    if (is_home()) {
        $homelink = '<li class="current_page_item">' . '<a href="' . esc_url(home_url('/')) . '">' . __('Home', 'rethink') . '</a></li>';
    } else {
        $homelink = '<li>' . '<a href="' . esc_url(home_url('/')) . '">' . __('Home', 'rethink') . '</a></li>';
    }
    $items = $homelink . $items;
    return $items;
}

add_filter('wp_list_pages', 'rethink_nav_menu_items');

/**
 * This function thumbnail id and
 * returns thumbnail image
 * @param type $iw
 * @param type $ih 
 */
function rethink_main_image() {
    global $post, $posts;
    //This is required to set to Null
    $id = '';
    $the_title = '';
    // Till Here
    $permalink = esc_url(get_permalink($id));
    $homeLink = get_template_directory_uri();
    $first_img = '';
    ob_start();
    ob_end_clean();
    $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
    if (isset($matches [1] [0])) {
        $first_img = $matches [1] [0];
    }
    if (!empty($first_img)) { //Defines a default image  
        print "<a href='" . esc_url($permalink) . "'><img src=" . esc_url($first_img) . "' width='250px' height='160px' class='postimg wp-post-image' alt='" . esc_attr($the_title) . "' /></a>";
}
}

/**
 * Prints HTML with meta information for the current post (category, tags and permalink).
 *
 */
function rethink_posted_in() {
// Retrieves tag list of current post, separated by commas.
    $tag_list = get_the_tag_list('', ', ');
    if ($tag_list) {
        $posted_in = __('This entry was posted in %1$s and tagged %2$s. Bookmark the ', 'rethink') . '<a href="%3$s" title="' . __('Permalink to %4$s', 'rethink') . '" rel="bookmark">' . __('permalink</a>.', 'rethink');
    } elseif (is_object_in_taxonomy(get_post_type(), 'category')) {
        $posted_in = __('This entry was posted in %1$s. Bookmark the ', 'rethink') . '<a href="%3$s" title="' . __('Permalink to %4$s', 'rethink') . '" rel="bookmark">' . __('permalink</a>.', 'rethink');
    } else {
        $posted_in = __('Bookmark the ', 'rethink') . '<a href="%3$s" title="' . __('Permalink to %4$s', 'rethink') . '" rel="bookmark">' . __('permalink</a>.', 'rethink');
    }
// Prints the string, replacing the placeholders.
    printf(
            $posted_in, get_the_category_list(', '), $tag_list, esc_url(get_permalink()), the_title_attribute('echo=0')
    );
}

/**
 * Register widgetized areas, including two sidebars and four widget-ready columns in the footer.
 *
 * To override twentyten_widgets_init() in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @uses register_sidebar
 */
function rethink_widgets_init() {
// Area 1, located at the top of the sidebar.
    register_sidebar(array(
        'name' => __('Primary Widget Area', 'rethink'),
        'id' => 'primary-widget-area',
        'description' => __('The primary widget area', 'rethink'),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '<h3>',
        'after_title' => '</h3>',
    ));
// Area 2, located below the Primary Widget Area in the sidebar. Empty by default.
    register_sidebar(array(
        'name' => __('Secondary Widget Area', 'rethink'),
        'id' => 'secondary-widget-area',
        'description' => __('The secondary widget area', 'rethink'),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '<h3>',
        'after_title' => '</h3>',
    ));
    // Area 3, located in the footer. Empty by default.
    register_sidebar(array(
        'name' => __('First Footer Widget Area', 'rethink'),
        'id' => 'first-footer-widget-area',
        'description' => __('The first footer widget area', 'rethink'),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '<h4>',
        'after_title' => '</h4>',
    ));
    // Area 4, located in the footer. Empty by default.
    register_sidebar(array(
        'name' => __('Second Footer Widget Area', 'rethink'),
        'id' => 'second-footer-widget-area',
        'description' => __('The second footer widget area', 'rethink'),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '<h4>',
        'after_title' => '</h4>',
    ));
    // Area 5, located in the footer. Empty by default.
    register_sidebar(array(
        'name' => __('Third Footer Widget Area', 'rethink'),
        'id' => 'third-footer-widget-area',
        'description' => __('The third footer widget area', 'rethink'),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '<h4>',
        'after_title' => '</h4>',
    ));
    // Area 6, located in the footer. Empty by default.
    register_sidebar(array(
        'name' => __('Fourth Footer Widget Area', 'rethink'),
        'id' => 'fourth-footer-widget-area',
        'description' => __('The fourth footer widget area', 'rethink'),
        'before_widget' => '',
        'after_widget' => '',
        'before_title' => '<h4>',
        'after_title' => '</h4>',
    ));
}

/** Register sidebars by running rethink_widgets_init() on the widgets_init hook. */
add_action('widgets_init', 'rethink_widgets_init');

/**
 * Pagination
 *
 */
function rethink_pagination($pages = '', $range = 2) {
    $showitems = ($range * 2) + 1;
    global $paged;
    if (empty($paged))
        $paged = 1;
    if ($pages == '') {
        global $wp_query;
        $pages = $wp_query->max_num_pages;
        if (!$pages) {
            $pages = 1;
        }
    }
    if (1 != $pages) {
        echo "<ul class='paging'>";
        if ($paged > 2 && $paged > $range + 1 && $showitems < $pages)
            echo "<li><a href='" . get_pagenum_link(1) . "'>&laquo;</a></li>";
        if ($paged > 1 && $showitems < $pages)
            echo "<li><a href='" . get_pagenum_link($paged - 1) . "'>&lsaquo;</a></li>";
        for ($i = 1; $i <= $pages; $i++) {
            if (1 != $pages && (!($i >= $paged + $range + 1 || $i <= $paged - $range - 1) || $pages <= $showitems )) {
                echo ($paged == $i) ? "<li><a href='" . get_pagenum_link($i) . "' class='current' >" . $i . "</a></li>" : "<li><a href='" . get_pagenum_link($i) . "' class='inactive' >" . $i . "</a></li>";
            }
        }
        if ($paged < $pages && $showitems < $pages)
            echo "<li><a href='" . get_pagenum_link($paged + 1) . "'>&rsaquo;</a></li>";
        if ($paged < $pages - 1 && $paged + $range - 1 < $pages && $showitems < $pages)
            echo "<li><a href='" . get_pagenum_link($pages) . "'>&raquo;</a></li>";
        echo "</ul>\n";
    }
}

/**
 * Fevicon
 */
function rethink_childtheme_favicon() {
    if (rethink_get_option('rethink_favicon') != '') {
        echo '<link rel="shortcut icon" href="' . esc_url(rethink_get_option('rethink_favicon')) . '"/>' . "\n";
    }
}
add_action('wp_head', 'rethink_childtheme_favicon');